@@ -1,5 +1,5 @@
 package Getopt::EX::LabeledParam;
-use version; our $VERSION = version->declare("2.1.6");
+use version; our $VERSION = version->declare("2.2.1");
 
 use v5.14;
 use warnings;
@@ -22,6 +22,7 @@ sub new {
 	CONCAT => "",
 	HASH => {},
 	LIST => [],
+	RESET => undef,
     }, $class;
 
     $obj->configure(@_) if @_;
@@ -52,7 +53,13 @@ sub list { @{ shift->{LIST} } }
 
 sub push_list {
     my $obj = shift;
-    push @{ $obj->{LIST} }, @_;
+    for (@_) {
+	if (defined $obj->{RESET} and $_ eq $obj->{RESET}) {
+	    @{ $obj->{LIST} } = ();
+	} else {
+	    push @{ $obj->{LIST} }, $_;
+	}
+    }
     $obj;
 }
 
@@ -272,6 +279,11 @@ it possible create a new hash entry.
 
 Set concatenation string inserted before appending string.
 
+=item B<RESET> =E<gt> I<string>
+
+Set B<reset> mark.  Undefined by default.  If this reset string is
+found in a list-type argument, the list is reset to empty.
+
 =back
 
 =item B<load_params> I<option>
